import { StyleSheet, FlatList as FlatList$1, ImageBackground as ImageBackground$1, KeyboardAvoidingView as KeyboardAvoidingView$1, Modal as Modal$1, Pressable as Pressable$1, ScrollView as ScrollView$1, SectionList as SectionList$1, Text as Text$1, TouchableHighlight as TouchableHighlight$1, TouchableOpacity as TouchableOpacity$1, TouchableWithoutFeedback as TouchableWithoutFeedback$1, SafeAreaView as SafeAreaView$1, View as View$1, VirtualizedList as VirtualizedList$1 } from 'react-native';
export { ActivityIndicator, Button, DrawerLayoutAndroid, Image, InputAccessoryView, RefreshControl, TouchableNativeFeedback } from 'react-native';
import React, { createContext, useContext } from 'react';

/**
 * This set of utilities + context allows React Native components to inherit
 * styles in the same way CSS does.
 */
/**
 * This should be the intersection of CSS properties defined
 * as inherited and React Native text styles that are
 * defined on the `TextStyle` type.
 *
 * @see https://www.sitepoint.com/css-inheritance-introduction/
 */
const inheritedStyles = [
    'color',
    'direction',
    'fontFamily',
    'fontSize',
    'fontStyle',
    'fontVariant',
    'fontWeight',
    'letterSpacing',
    'lineHeight',
    'textAlign',
    'textDecorationColor',
    'textShadowColor',
    'textShadowOffset',
    'textShadowRadius',
    'textTransform'
];
/**
 * For now, the only root style / property guaranteed is the `color` prop
 */
const rootStyles = {
    color: 'black'
};
const StyleContext = createContext(rootStyles);
const useStyles = (style) => {
    const inherited = useContext(StyleContext);
    if (!style) {
        return [inherited, undefined];
    }
    let newContext;
    const newStyles = Object.entries(StyleSheet.flatten(style)).filter(([_, value]) => value !== undefined);
    const hasInheritedStyles = newStyles.find(([key]) => inheritedStyles.includes(key));
    if (hasInheritedStyles) {
        newContext = [];
    }
    const finalStyleEntries = Object.entries(inherited)
        .concat(newStyles);
    let finalStyle = Object.fromEntries(finalStyleEntries);
    finalStyle = Object.fromEntries(finalStyleEntries.map(([key, value]) => {
        if (typeof value === 'string') {
            value = value.replace(/currentColor/g, finalStyle.color);
        }
        const finalValue = [key, value];
        if (hasInheritedStyles &&
            inheritedStyles.includes(key)) {
            newContext.push(finalValue);
        }
        return finalValue;
    }));
    return [
        finalStyle,
        hasInheritedStyles
            ? Object.fromEntries(newContext)
            : undefined
    ];
};

const wrapContext = (Component) => {
    if (!Component) {
        return undefined;
    }
    return ({ style, ...props }) => {
        const [finalStyle, newContext] = useStyles(style);
        // @ts-ignore - not sure how to properly type this
        const JSX = React.createElement(Component, { style: finalStyle, ...props });
        if (newContext) {
            return (React.createElement(StyleContext.Provider, { value: newContext }, JSX));
        }
        return JSX;
    };
};

/**
 * These are asserted as not `undefined` for testing,
 * but they may be undefined at runtime if the underlying
 * React Native component is undefined at export time.
 */
const FlatList = wrapContext(FlatList$1);
const ImageBackground = wrapContext(ImageBackground$1);
const KeyboardAvoidingView = wrapContext(KeyboardAvoidingView$1);
const Modal = wrapContext(Modal$1);
const Pressable = wrapContext(Pressable$1);
const ScrollView = wrapContext(ScrollView$1);
const SectionList = wrapContext(SectionList$1);
const Text = wrapContext(Text$1);
const TouchableHighlight = wrapContext(TouchableHighlight$1);
const TouchableOpacity = wrapContext(TouchableOpacity$1);
const TouchableWithoutFeedback = wrapContext(TouchableWithoutFeedback$1);
const SafeAreaView = wrapContext(SafeAreaView$1);
const View = wrapContext(View$1);
const VirtualizedList = wrapContext(VirtualizedList$1);

export { FlatList, ImageBackground, KeyboardAvoidingView, Modal, Pressable, SafeAreaView, ScrollView, SectionList, Text, TouchableHighlight, TouchableOpacity, TouchableWithoutFeedback, View, VirtualizedList };
//# sourceMappingURL=index.js.map
